### 请使用termux 并且运行以下命令确保环境完整
```shell
pkg update #初次安装termux更新源
pkg install android-tools #安装adb
pkg install python #安装python
pip install flask #安装flask
pip install adb-chix #安装炽心adb
adb-chix #启动adb web服务
```